@@ -29,11 +29,10 @@ class LaunchApp : public QObject
     Q_OBJECT
 
 public:
-    LaunchApp(QObject *parent = Q_NULLPTR);
+    explicit LaunchApp(QObject *parent = Q_NULLPTR);
 
 public Q_SLOTS:
     bool runCommand(const QString &exe, const QStringList &args = QStringList());
-    bool runUrl(const QString &url, const QString &mimeType);
 };
 
 #endif // LAUNCHAPP_H
